@@ -1290,8 +1290,9 @@ class Listener(Participant):
     """
 
     def __init__(self, scope,
-                 config       = None,
-                 configurator = None):
+                 config            = None,
+                 configurator      = None,
+                 receivingStrategy = None):
         """
         Create a new L{Listener} for B{scope}.
 
@@ -1321,7 +1322,8 @@ class Listener(Participant):
             connectors = self.getConnectors('in', config)
             for connector in connectors:
                 connector.setQualityOfServiceSpec(config.getQualityOfServiceSpec())
-            self.__configurator = rsb.eventprocessing.InRouteConfigurator(connectors = connectors)
+            self.__configurator = rsb.eventprocessing.InRouteConfigurator(connectors = connectors,
+                                                                          receivingStrategy = receivingStrategy)
         self.__configurator.setScope(scope)
 
         self.__activate()
